==> mupad-1.4.2.tgz: mupad/share/mmg/include/kernel/MST_stack.h <==
/* $Date: 1997/09/15 11:36:32 $  $Author: tonner $  $Revision: 1.16 $ */

/**************************************************************************/
/* FILE:             MST_stack.h                                          */
/* Autor:            Andreas Kemper                                       */
/* Erstellt:         25/04/91                                             */
/* Letzte Aenderung: 14/05/93                                             */
/**************************************************************************/

#ifndef __MST_stack__
#define __MST_stack__


#ifdef DOS_FILENAMES
#  include "MUP_typ.h"
#else
#  include "MUP_types.h"
#endif


/**************************************************************************/
/* MSTToption                                                             */
/* Mit Hilfe dieser Option k"onnen den Stack-Funktionen weitere           */
/* Informationen "ubergeben werden.                                       */
/**************************************************************************/
typedef long MSTToption ;

#define MSTC_option_non            0
#define MSTC_option_standard       0
#define MSTC_option_locked         1
#define MSTC_option_lock           2
#define MSTC_option_force          4

/**************************************************************************/
/* MSTTinfo -- IST NUN IN `MUP_types.h' DEFINIERT                         */
/* In einer Variablen diesen Typs werden in jeder Schachtel eines Stacks  */
/* weitere Informationen gespeichert.                                     */
/**************************************************************************/
/* typedef long MSTTinfo ; */

#define MSTC_info_standard         0
#define MSTC_info_volatile         1
#define MSTC_info_info           255

#define MSTC_info_lock           256

/**************************************************************************/
/* Im Mem-Teil der obersten Stack-Schachtel werden Informationen          */
/* gespeichert. Mit den folgenden Konstanten k"onnen diese Informationen  */
/* ausgelesen werden.                                                     */
/**************************************************************************/
#define MSTC_stack_protected     3
#define MSTC_stack_non           0
#define MSTC_stack_warning       1
#define MSTC_stack_error         2
#define MSTC_stack_user          3

/**************************************************************************/
/* Variablen                                                              */
/**************************************************************************/
extern long MSTVparallel ;

/**************************************************************************/
/* Deklaration der Prozeduren zur Behandlung des Stacks.                  */
/**************************************************************************/
void MST_delete_referenceitems ( S_Pointer list, long number ) ;


/**************************************************************************/
/* void MST_stack_for_ident(S_Pointer *stack,*ident)                      */
/* Diese Funktion gibt den zu *string geh"orenden Stack zur"uck.          */
/**************************************************************************/
#define MST_stack_for_ident(stack,ident) \
              { *(stack) = *MMMP(ident, 2, MMMread) ; \
                MMMinactiv ( ident ) ; }

/**************************************************************************/
/* void MST_stack_for_string(S_Pointer *stack,*string)                    */
/* Diese Funktion gibt den zu *string geh"orenden Stack zur"uck.          */
/**************************************************************************/
#define MST_stack_for_string(stack,string) \
              { *(stack) = MNS_index(MNSV_global_namespace, *string) ;\
                MMMfree( *(stack) ) ; }
/**************************************************************************/
/* void MST_del_stack(S_Pointer ident, MSTToption option,                 */
/*                    MSTTinfo *info, MEVTstamp *stamp, long *procdepth)  */
/**************************************************************************/
#define MST_del_stack(ident, option, info, stamp, procdepth) \
	(void) MST_del_item(ident, option, info, stamp, procdepth, _false_)


void       MST_init(VOID);
void       MST_exit(VOID);
void       MST_set_environment_variables(VOID);

S_Pointer  MST_new_stack   ( S_Pointer value, S_Pointer writefunc, S_Pointer readfunc );
void       MST_ins_stack   ( S_Pointer   ident, 
                             S_Pointer   value, 
                             MSTToption  , 
                             MSTTinfo   *, 
                             MEVTstamp  *, 
                             long       *procdepth);

void       MST_ins_stack_string( S_Pointer ident,
                             S_Pointer   value,
                             MSTToption  ,
                             MSTTinfo   *,
                             MEVTstamp  *,
                             long       *procdepth);

S_Pointer  MST_del_item    ( S_Pointer   ident, 
                             MSTToption  , 
                             MSTTinfo   *, 
                             MEVTstamp  *, 
                             long       *procdepth,
                             MUPbool    );

void       MST_del_stack_string( S_Pointer   string,
                             MSTToption  ,   
                             MSTTinfo   *, 
                             MEVTstamp  *, 
                             long       *procdepth);

S_Pointer MST_replace_ident (S_Pointer   ident, 
                             S_Pointer   value, 
                             MSTToption  , 
                             MSTTinfo   *, 
                             MEVTstamp  *, 
                             long       *procdepth );
void       MST_write_string( S_Pointer   string,
                             S_Pointer   value,
                             MSTToption  ,
                             MSTTinfo   *,
                             MEVTstamp  *,
                             long       *procdepth );
S_Pointer  MST_read_ident  ( S_Pointer  ident, 
                             long       eval_type, 
                             MSTToption  , 
                             MSTTinfo   *, 
                             MEVTstamp  *, 
                             long       *procdepth);
S_Pointer  MST_read_string ( S_Pointer  string,
                             long       eval_type,
                             MSTToption  ,  
                             MSTTinfo   *,
                             MEVTstamp  *,
                             long       *procdepth);
void       MST_write_info  ( S_Pointer   stack, 
                             MSTTinfo    newinfo, 
                             MSTToption  , 
                             MSTTinfo   *, 
                             MEVTstamp  *, 
                             long       *procdepth );
S_Pointer MST_replace_value (S_Pointer   stack, 
                             S_Pointer   value, 
                             MSTToption  option, 
                             MSTTinfo   *info, 
                             MEVTstamp  *stamp, 
                             long       *procdepth,
                             S_Pointer  ident      );

void       MST_lock        ( S_Pointer stack, 
                             MSTToption, 
                             MSTTinfo *, 
                             MEVTstamp *, 
                             long *procdepth );

S_Pointer  MST_stack_content( VOID );
void       MST_reset_stack  ( long );

S_Pointer  MST_read_netglobal ( S_Pointer   stack, 
                                MSTToption  , 
                                MSTTinfo   * );
void       MST_set_netglobal  ( S_Pointer   stack, 
                                S_Pointer   value, 
                                MSTToption  , 
                                MSTTinfo   * );
void       MST_lock_netglobal ( S_Pointer   stack, 
                                MSTToption  , 
                                MSTTinfo   * );

S_Pointer  MST_read_global    ( S_Pointer stack );
void       MST_set_global     ( S_Pointer stack, S_Pointer value );

void       MST_insert_code_objects( VOID );

void	   MST_check_protection( S_Pointer s );

S_Pointer  MST_eval_properties  ( S_Pointer s,
                                long      prev_func,
                                long      eval_type,
                                S_Pointer exec );

inline void
MST_write_ident ( S_Pointer   ident, 
                  S_Pointer   value, 
                  MSTToption  opt, 
                  MSTTinfo   *info, 
                  MEVTstamp  *stamp, 
                  long       *depth )
{
    S_Pointer res = MST_replace_ident(ident, value, opt, info, stamp, depth);
    MMMfree(res);
}

inline void
MST_write_value ( S_Pointer   stack, 
                  S_Pointer   value, 
                  MSTToption  option, 
                  MSTTinfo   *info, 
                  MEVTstamp  *stamp, 
                  long       *procdepth,
                  S_Pointer  ident )
{
    S_Pointer res = MST_replace_value(stack, value, option, info, stamp,
				      procdepth, ident);
    MMMfree(res);
}

#endif /* __MST_stack__ */

==> mupad-2.0.0.tgz: mupad/share/mmg/include/kernel/MST_stack.h <==
/* $Date: 1999/02/02 08:16:33 $  $Author: jerry $  $Revision: 1.3 $ */

/**************************************************************************/
/* FILE:             MST_stack.h                                          */
/* Autor:            Andreas Kemper                                       */
/* Erstellt:         25/04/91                                             */
/* Letzte Aenderung: 14/05/93                                             */
/**************************************************************************/

#ifndef __MST_stack__
#define __MST_stack__


#ifdef DOS_FILENAMES
#  include "MUP_typ.h"
#else
#  include "MUP_types.h"
#endif


/**************************************************************************/
/* MSTToption                                                             */
/* Mit Hilfe dieser Option k"onnen den Stack-Funktionen weitere           */
/* Informationen "ubergeben werden.                                       */
/**************************************************************************/
typedef long MSTToption ;

#define MSTC_option_non            0
#define MSTC_option_standard       0
#define MSTC_option_locked         1
#define MSTC_option_lock           2
#define MSTC_option_force          4

/**************************************************************************/
/* MSTTinfo -- IST NUN IN `MUP_types.h' DEFINIERT                         */
/* In einer Variablen diesen Typs werden in jeder Schachtel eines Stacks  */
/* weitere Informationen gespeichert.                                     */
/**************************************************************************/
/* typedef long MSTTinfo ; */

#define MSTC_info_standard         0
#define MSTC_info_volatile         1
#define MSTC_info_info           255

#define MSTC_info_lock           256

/**************************************************************************/
/* Im Mem-Teil der obersten Stack-Schachtel werden Informationen          */
/* gespeichert. Mit den folgenden Konstanten k"onnen diese Informationen  */
/* ausgelesen werden.                                                     */
/**************************************************************************/
#define MSTC_stack_protected     3
#define MSTC_stack_non           0
#define MSTC_stack_warning       1
#define MSTC_stack_error         2
#define MSTC_stack_user          3

/**************************************************************************/
/* Variablen                                                              */
/**************************************************************************/
extern long MSTVparallel ;

/**************************************************************************/
/* Deklaration der Prozeduren zur Behandlung des Stacks.                  */
/**************************************************************************/
void MST_delete_referenceitems ( S_Pointer list, long number ) ;


/**************************************************************************/
/* void MST_stack_for_ident(S_Pointer *stack,*ident)                      */
/* Diese Funktion gibt den zu *string geh"orenden Stack zur"uck.          */
/**************************************************************************/
#define MST_stack_for_ident(stack,ident) \
              { *(stack) = *MMMP(ident, 2, MMMread) ; \
                MMMinactiv ( ident ) ; }

/**************************************************************************/
/* void MST_stack_for_string(S_Pointer *stack,*string)                    */
/* Diese Funktion gibt den zu *string geh"orenden Stack zur"uck.          */
/**************************************************************************/
#define MST_stack_for_string(stack,string) \
              { *(stack) = MNS_index(MNSV_global_namespace, *string) ;\
                MMMfree( *(stack) ) ; }
/**************************************************************************/
/* void MST_del_stack(S_Pointer ident, MSTToption option,                 */
/*                    MSTTinfo *info, MEVTstamp *stamp, long *procdepth)  */
/**************************************************************************/
#define MST_del_stack(ident, option, info, stamp, procdepth) \
	(void) MST_del_item(ident, option, info, stamp, procdepth, _false_)


void       MST_init();
void       MST_exit();
void       MST_set_environment_variables();

S_Pointer  MST_new_stack   ( S_Pointer value, S_Pointer writefunc, S_Pointer readfunc );
void       MST_ins_stack   ( S_Pointer   ident, 
                             S_Pointer   value, 
                             MSTToption  , 
                             MSTTinfo   *, 
                             MEVTstamp  *, 
                             long       *procdepth);

void       MST_ins_stack_string( S_Pointer ident,
                             S_Pointer   value,
                             MSTToption  ,
                             MSTTinfo   *,
                             MEVTstamp  *,
                             long       *procdepth);

S_Pointer  MST_del_item    ( S_Pointer   ident, 
                             MSTToption  , 
                             MSTTinfo   *, 
                             MEVTstamp  *, 
                             long       *procdepth,
                             MUPbool    );

void       MST_del_stack_string( S_Pointer   string,
                             MSTToption  ,   
                             MSTTinfo   *, 
                             MEVTstamp  *, 
                             long       *procdepth);

S_Pointer MST_replace_ident (S_Pointer   ident, 
                             S_Pointer   value, 
                             MSTToption  , 
                             MSTTinfo   *, 
                             MEVTstamp  *, 
                             long       *procdepth );
void       MST_write_string( S_Pointer   string,
                             S_Pointer   value,
                             MSTToption  ,
                             MSTTinfo   *,
                             MEVTstamp  *,
                             long       *procdepth );
S_Pointer  MST_read_ident  ( S_Pointer  ident, 
                             long       eval_type, 
                             MSTToption  , 
                             MSTTinfo   *, 
                             MEVTstamp  *, 
                             long       *procdepth);
S_Pointer  MST_read_string ( S_Pointer  string,
                             long       eval_type,
                             MSTToption  ,  
                             MSTTinfo   *,
                             MEVTstamp  *,
                             long       *procdepth);
void       MST_write_info  ( S_Pointer   stack, 
                             MSTTinfo    newinfo, 
                             MSTToption  , 
                             MSTTinfo   *, 
                             MEVTstamp  *, 
                             long       *procdepth );
S_Pointer MST_replace_value (S_Pointer   stack, 
                             S_Pointer   value, 
                             MSTToption  option, 
                             MSTTinfo   *info, 
                             MEVTstamp  *stamp, 
                             long       *procdepth,
                             S_Pointer  ident      );

void       MST_lock        ( S_Pointer stack, 
                             MSTToption, 
                             MSTTinfo *, 
                             MEVTstamp *, 
                             long *procdepth );

S_Pointer  MST_stack_content(  );
void       MST_reset_stack  ( long );

S_Pointer  MST_read_netglobal ( S_Pointer   stack, 
                                MSTToption  , 
                                MSTTinfo   * );
void       MST_set_netglobal  ( S_Pointer   stack, 
                                S_Pointer   value, 
                                MSTToption  , 
                                MSTTinfo   * );
void       MST_lock_netglobal ( S_Pointer   stack, 
                                MSTToption  , 
                                MSTTinfo   * );

S_Pointer  MST_read_global    ( S_Pointer stack );
void       MST_set_global     ( S_Pointer stack, S_Pointer value );

void       MST_insert_code_objects(  );

void	   MST_check_protection( S_Pointer s );

S_Pointer  MST_eval_properties  ( S_Pointer s,
                                long      prev_func,
                                long      eval_type,
                                S_Pointer exec );

inline void
MST_write_ident ( S_Pointer   ident, 
                  S_Pointer   value, 
                  MSTToption  opt, 
                  MSTTinfo   *info, 
                  MEVTstamp  *stamp, 
                  long       *depth )
{
    S_Pointer res = MST_replace_ident(ident, value, opt, info, stamp, depth);
    MMMfree(res);
}

inline void
MST_write_value ( S_Pointer   stack, 
                  S_Pointer   value, 
                  MSTToption  option, 
                  MSTTinfo   *info, 
                  MEVTstamp  *stamp, 
                  long       *procdepth,
                  S_Pointer  ident )
{
    S_Pointer res = MST_replace_value(stack, value, option, info, stamp,
				      procdepth, ident);
    MMMfree(res);
}

#endif /* __MST_stack__ */
